@@ -24,7 +24,7 @@
   without including the source code for Qt in the source distribution.
 */
 
-#include "config-korganizer.h"
+#include <config-korganizer.h>
 #include "alarmdialog.h"
 #include "korganizer_interface.h"
 #include "mailclient.h"
@@ -49,14 +49,12 @@
 #include <MailTransport/TransportManager>
 #include <QUrl>
 
-#include <KLocale>
 #include <KComboBox>
 #include <QHBoxLayout>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
 #include <KSharedConfig>
-#include <KSystemTimeZone>
 #include <KToolInvocation>
 #include <KWindowSystem>
 #include <KIconLoader>
@@ -76,7 +74,7 @@ using namespace KCalCore;
 using namespace KCalUtils;
 
 static int defSuspendVal = 5;
-static int defSuspendUnit = 0; // 0=>minutes, 1=>hours, 2=>days, 3=>weeks
+static int defSuspendUnit = AlarmDialog::SuspendInMinutes;
 
 class ReminderTreeItem : public QTreeWidgetItem
 {
@@ -92,7 +90,7 @@ public:
     const Akonadi::Item mIncidence;
     QDateTime mRemindAt;
     QDateTime mTrigger;
-    KDateTime mHappening;
+    QDateTime mHappening;
     bool mNotified;
 };
 
@@ -136,6 +134,8 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup generalConfig(config, "General");
     QPoint pos = generalConfig.readEntry("Position", QPoint(0, 0));
+    int suspendVal = generalConfig.readEntry("SuspendValue", defSuspendVal);
+    SuspendUnit suspendUnit = static_cast<SuspendUnit>(generalConfig.readEntry("SuspendUnit", defSuspendUnit));
 
     QWidget *topBox = new QWidget(this);
     if (!pos.isNull()) {
@@ -236,7 +236,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     mSuspendSpin = new QSpinBox(suspendBox);
     suspendBoxHBoxLayout->addWidget(mSuspendSpin);
     mSuspendSpin->setRange(1, 9999);
-    mSuspendSpin->setValue(defSuspendVal);    // default suspend duration
+    mSuspendSpin->setValue(suspendVal);    // default suspend duration
     mSuspendSpin->setToolTip(
         i18nc("@info:tooltip",
               "Suspend the reminders by this amount of time"));
@@ -263,7 +263,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
               "using this time unit. You can set the number of time units "
               "in the adjacent number entry input."));
 
-    mSuspendUnit->setCurrentIndex(defSuspendUnit);
+    mSuspendUnit->setCurrentIndex(static_cast<int>(suspendUnit));
 
     connect(&mSuspendTimer, &QTimer::timeout, this, &AlarmDialog::wakeUp);
 
@@ -320,15 +320,14 @@ void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem,
         item = new ReminderTreeItem(incidenceitem, mIncidenceTree);
     }
     item->mNotified = false;
-    item->mHappening = KDateTime();
+    item->mHappening = QDateTime();
     item->mRemindAt = reminderAt;
     item->mTrigger = QDateTime::currentDateTime();
     item->mDisplayText = displayText;
     item->setText(0, cleanSummary(incidence->summary()));
 
     QString displayStr;
-    const KDateTime dateTime = triggerDateForIncidence(incidence, reminderAt,
-                               displayStr);
+    const auto dateTime = triggerDateForIncidence(incidence, reminderAt, displayStr);
 
     if (incidence->type() == Incidence::TypeEvent) {
         item->setIcon(0, QIcon::fromTheme(QStringLiteral("view-calendar-day")));
@@ -343,9 +342,7 @@ void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem,
     QString tip =
         IncidenceFormatter::toolTipStr(
             CalendarSupport::displayName(mCalendar.data(), incidenceitem.parentCollection()),
-            incidence,
-            item->mRemindAt.date(), true,
-            KDateTime::Spec::LocalZone());
+            incidence, item->mRemindAt.date(), true);
     if (!item->mDisplayText.isEmpty()) {
         tip += QLatin1String("<br>") + item->mDisplayText;
     }
@@ -461,26 +458,18 @@ void AlarmDialog::suspend()
 
     int unit = 1;
     switch (mSuspendUnit->currentIndex()) {
-    case 3: // weeks
+    case SuspendInWeeks:
         unit *=  7;
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
-    case 2: // days
+    case SuspendInDays:
         unit *= 24;
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
-    case 1: // hours
+    case SuspendInHours:
         unit *= 60;
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
-    case 0: // minutes
+    case SuspendInMinutes:
         unit *= 60;
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
     default:
         break;
     }
@@ -493,9 +482,9 @@ void AlarmDialog::suspend()
             (*it)->setDisabled(true);
             ReminderTreeItem *item = static_cast<ReminderTreeItem *>(*it);
             item->mRemindAt = QDateTime::currentDateTime().addSecs(unit * mSuspendSpin->value());
-            item->mHappening = KDateTime(item->mRemindAt, KDateTime::Spec::LocalZone());
+            item->mHappening = item->mRemindAt;
             item->mNotified = false;
-            (*it)->setText(1, KLocale::global()->formatDateTime(item->mHappening));
+            (*it)->setText(1, QLocale().toString(item->mHappening, QLocale::ShortFormat));
             selitem = item;
         }
         ++it;
@@ -672,9 +661,7 @@ void AlarmDialog::eventNotification()
                     subject = i18nc("@title", "Reminder: %1", alarm->mailSubject());
                 }
 
-                QString body =
-                    IncidenceFormatter::mailBodyStr(
-                        parent.staticCast<IncidenceBase>(), KSystemTimeZones::local());
+                QString body = IncidenceFormatter::mailBodyStr(parent.staticCast<IncidenceBase>());
                 if (!alarm->mailText().isEmpty()) {
                     body += QLatin1Char('\n') + alarm->mailText();
                 }
@@ -745,6 +732,9 @@ void AlarmDialog::slotSave()
 
     generalConfig.writeEntry("Reminders", numReminders);
     generalConfig.writeEntry("Position", pos());
+    generalConfig.writeEntry("SuspendValue", mSuspendSpin->value());
+    generalConfig.writeEntry("SuspendUnit", mSuspendUnit->currentIndex());
+
     config->sync();
 }
 
@@ -863,30 +853,27 @@ void AlarmDialog::accept()
 }
 
 /** static */
-KDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence,
+QDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence,
         const QDateTime &reminderAt,
         QString &displayStr)
 {
-    KDateTime result;
+    QDateTime result;
 
     if (incidence->alarms().isEmpty()) {
         return result;
     }
 
     if (incidence->recurs()) {
-        result = incidence->recurrence()->getNextDateTime(
-                     KDateTime(reminderAt, KDateTime::Spec::LocalZone()));
-
-        displayStr = KLocale::global()->formatDateTime(result.toLocalZone());
+        result = incidence->recurrence()->getNextDateTime(reminderAt).toLocalTime();
     }
 
     if (!result.isValid()) {
-        result = incidence->dateTime(Incidence::RoleAlarm);
-        displayStr = IncidenceFormatter::dateTimeToString(result, false,
-                     true,
-                     KDateTime::Spec::LocalZone());
+        result = incidence->dateTime(Incidence::RoleAlarm).toLocalTime();
     }
 
+    if (result.isValid()) {
+        displayStr = QLocale().toString(result, QLocale::ShortFormat);
+    }
     return result;
 }
 
@@ -905,9 +892,7 @@ void AlarmDialog::slotCalendarChanged()
 
             // Yes, alarms can be empty, if someone edited the incidence and removed all alarms
             if (!incidence->alarms().isEmpty()) {
-                const KDateTime dateTime = triggerDateForIncidence(incidence,
-                                           item->mRemindAt,
-                                           displayStr);
+                const auto dateTime = triggerDateForIncidence(incidence, item->mRemindAt, displayStr);
 
                 const QString summary = cleanSummary(incidence->summary());
 
@@ -1041,4 +1026,3 @@ void AlarmDialog::removeFromConfig(const QList<Akonadi::Item::Id> &ids)
     }
     genGroup.sync();
 }
-
