@@ -42,6 +42,7 @@
 #include <KCheckableProxyModel>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KSharedConfig>
 #include <QApplication>
 
 #include "koalarmclient_debug.h"
@@ -216,9 +217,7 @@ void KOAlarmClient::checkAlarms()
 
     qCDebug(KOALARMCLIENT_LOG) << "Check:" << from.toString() << " -" << mLastChecked.toString();
 
-    const Alarm::List alarms = mCalendar->alarms(KDateTime(from, KDateTime::LocalZone),
-                               KDateTime(mLastChecked, KDateTime::LocalZone),
-                               true /* exclude blocked alarms */);
+    const Alarm::List alarms = mCalendar->alarms(from, mLastChecked, true /* exclude blocked alarms */);
 
     for (const Alarm::Ptr &alarm : alarms) {
         const QString uid = alarm->customProperty("ETMCalendar", "parentUid");
@@ -237,7 +236,10 @@ void KOAlarmClient::createReminder(const Akonadi::ETMCalendar::Ptr &calendar,
     if (!CalendarSupport::hasIncidence(aitem)) {
         return;
     }
-
+    if (remindAtDate.addDays(10) < mLastChecked) {
+        // ignore reminders more than 10 days old
+        return;
+    }
     if (!mDialog) {
         mDialog = new AlarmDialog(calendar);
         connect(this, &KOAlarmClient::saveAllSignal, mDialog, &AlarmDialog::slotSave);
@@ -295,9 +297,8 @@ QString KOAlarmClient::dumpDebug() const
 
 QStringList KOAlarmClient::dumpAlarms() const
 {
-    const KDateTime start = KDateTime(QDateTime::currentDateTime().date(),
-                                      QTime(0, 0), KDateTime::LocalZone);
-    const KDateTime end = start.addDays(1).addSecs(-1);
+    const QDateTime start = QDateTime(QDate::currentDate(), QTime(0, 0), Qt::LocalTime);
+    const QDateTime end = start.addDays(1).addSecs(-1);
 
     QStringList lst;
     const Alarm::List alarms = mCalendar->alarms(start, end);
@@ -341,4 +342,3 @@ void KOAlarmClient::show()
         }
     }
 }
-
