@@ -56,15 +56,13 @@ public:
 public Q_SLOTS:
     void slotQuit();
 
-protected Q_SLOTS:
-    void deferredInit();
-    void checkAlarms();
-
 Q_SIGNALS:
     void reminderCount(int);
     void saveAllSignal();
 
 private:
+    void deferredInit();
+    void checkAlarms();
     void setupAkonadi();
     void slotCommitData(QSessionManager &);
     bool dockerEnabled();
@@ -74,14 +72,14 @@ private:
                         const QDateTime &dt, const QString &displayText);
     void saveLastCheckTime();
 
-    AlarmDockWindow *mDocker;  // the panel icon
+    AlarmDockWindow *mDocker = nullptr;  // the panel icon
     Akonadi::ETMCalendar::Ptr mCalendar;
-    Akonadi::EntityTreeModel *mETM;
+    Akonadi::EntityTreeModel *mETM = nullptr;
 
     QDateTime mLastChecked;
     QTimer mCheckTimer;
 
-    AlarmDialog *mDialog;
+    AlarmDialog *mDialog = nullptr;
 };
 
 #endif
