@@ -27,7 +27,7 @@
   with any edition of Qt, and distribute the resulting executable,
   without including the source code for Qt in the source distribution.
 */
-#include "config-korganizer.h"
+#include <config-korganizer.h>
 #include "actionmanager.h"
 #include "akonadicollectionview.h"
 #include "calendaradaptor.h"
@@ -39,8 +39,9 @@
 #include "prefs/koprefs.h"
 #include "koviewmanager.h"
 #include "kowindowlist.h"
-#include "KdepimDBusInterfaces/ReminderClient"
 #include "kocheckableproxymodel.h"
+#include <KAuthorized>
+#include "KdepimDBusInterfaces/ReminderClient"
 
 #include <KHolidays/HolidayRegion>
 
@@ -70,11 +71,9 @@
 #include <QAction>
 #include <KActionCollection>
 #include <QFileDialog>
-#include <QFileDialog>
 #include <QMenu>
 #include <QMenuBar>
 #include <KMessageBox>
-#include <KMimeTypeTrader>
 #include <KProcess>
 #include <KSelectAction>
 #include <KShortcutsDialog>
@@ -208,13 +207,17 @@ void ActionManager::createCalendarAkonadi()
     mCalendarView->addExtension(&factory);
     mCollectionView = factory.collectionView();
     mCollectionView->setObjectName(QStringLiteral("Resource View"));
-    connect(mCollectionView, &AkonadiCollectionView::resourcesAddedRemoved, this, &ActionManager::slotResourcesAddedRemoved);
+    connect(mCollectionView, &AkonadiCollectionView::resourcesAddedRemoved,
+            this, &ActionManager::slotResourcesAddedRemoved);
+
     connect(mCollectionView, &AkonadiCollectionView::defaultResourceChanged,
             this, &ActionManager::slotDefaultResourceChanged);
-    connect(mCollectionView, SIGNAL(colorsChanged()),
-            mCalendarView, SLOT(updateConfig()));
 
-    mCollectionViewStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group("GlobalCollectionView"));
+    connect(mCollectionView, &AkonadiCollectionView::colorsChanged,
+            mCalendarView, QOverload<>::of(&CalendarView::updateConfig));
+
+    mCollectionViewStateSaver =
+        new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group("GlobalCollectionView"));
     mCollectionViewStateSaver->setView(mCollectionView->view());
 
     KCheckableProxyModel *checkableProxy = calendar()->checkableProxyModel();
@@ -222,7 +225,8 @@ void ActionManager::createCalendarAkonadi()
 
     mCollectionView->setCollectionSelectionProxyModel(checkableProxy);
 
-    CalendarSupport::CollectionSelection *collectionSelection = new CalendarSupport::CollectionSelection(selectionModel);
+    CalendarSupport::CollectionSelection *collectionSelection =
+        new CalendarSupport::CollectionSelection(selectionModel);
     EventViews::EventView::setGlobalCollectionSelection(collectionSelection);
 
     mCalendarView->readSettings();
@@ -233,12 +237,11 @@ void ActionManager::createCalendarAkonadi()
 
     calendar()->setOwner(KCalCore::Person::Ptr(new KCalCore::Person(CalendarSupport::KCalPrefs::instance()->fullName(),
                          CalendarSupport::KCalPrefs::instance()->email())));
-
 }
 
 void ActionManager::initActions()
 {
-    QAction *action;
+    QAction *action = nullptr;
 
     /*************************** FILE MENU **********************************/
 
@@ -254,7 +257,7 @@ void ActionManager::initActions()
         a = mACollection->addAction(KStandardAction::PrintPreview, mCalendarView, SLOT(printPreview()));
         mACollection->addAction(QStringLiteral("korganizer_print_preview"), a);
     } else {
-        KStandardAction::open(this, SLOT(file_open()), mACollection);
+        KStandardAction::open(this, QOverload<>::of(&ActionManager::file_open), mACollection);
         KStandardAction::print(mCalendarView, &CalendarView::print, mACollection);
         KStandardAction::printPreview(mCalendarView, &CalendarView::printPreview, mACollection);
     }
@@ -268,31 +271,16 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("import_icalendar"), mImportAction);
     connect(mImportAction, &QAction::triggered, this, &ActionManager::file_import);
 
-    QAction *importAction = new QAction(i18n("&Import From UNIX Ical Tool"), this);
-    setHelpText(importAction, i18n("Import a calendar in another format"));
-    importAction->setWhatsThis(
-        i18n("Select this menu entry if you would like to import the contents "
-             "of a non-iCalendar formatted file into your current calendar."));
-    mACollection->addAction(QStringLiteral("import_ical"), importAction);
-    connect(importAction, &QAction::triggered, this, &ActionManager::file_icalimport);
-
-    action = new QAction(i18n("Get &Hot New Stuff..."), this);
-    mACollection->addAction(QStringLiteral("downloadnewstuff"), action);
-    connect(action, &QAction::triggered, this, &ActionManager::downloadNewStuff);
+    if (KAuthorized::authorize(QStringLiteral("ghns"))) {
+        action = new QAction(i18n("Get &Hot New Stuff..."), this);
+        mACollection->addAction(QStringLiteral("downloadnewstuff"), action);
+        connect(action, &QAction::triggered, this, &ActionManager::downloadNewStuff);
+    }
 
     action = new QAction(i18n("Export as &iCalendar..."), this);
     mACollection->addAction(QStringLiteral("export_icalendar"), action);
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::exportICalendar);
 
-    action = new QAction(i18n("Export as &vCalendar..."), this);
-    mACollection->addAction(QStringLiteral("export_vcalendar"), action);
-    connect(action, &QAction::triggered, mCalendarView, &CalendarView::exportVCalendar);
-
-    //Laurent: 2009-03-24 comment it until upload will implement
-    //action = new QAction( i18n( "Upload &Hot New Stuff..." ), this );
-    //mACollection->addAction( "uploadnewstuff", action );
-    //connect( action, SIGNAL(triggered(bool)), SLOT(uploadNewStuff()) );
-
     action = new QAction(i18n("Archive O&ld Entries..."), this);
     mACollection->addAction(QStringLiteral("file_archive"), action);
     connect(action, &QAction::triggered, this, &ActionManager::file_archive);
@@ -303,7 +291,7 @@ void ActionManager::initActions()
 
     /************************** EDIT MENU *********************************/
 
-    QAction *pasteAction;
+    QAction *pasteAction = nullptr;
     Akonadi::History *history = mCalendarView->history();
     if (mIsPart) {
         // edit menu
@@ -380,15 +368,10 @@ void ActionManager::initActions()
     connect(action, &QAction::triggered, mCalendarView->viewManager(),
             &KOViewManager::showTimeLineView);
 
-    action = new QAction(QIcon::fromTheme(QStringLiteral("view-calendar-time-spent")), i18n("Time&spent"), this);
-    mACollection->addAction(QStringLiteral("view_timespent"), action);
-    connect(action, &QAction::triggered, mCalendarView->viewManager(),
-            &KOViewManager::showTimeSpentView);
-
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~ REFRESH ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     action = new QAction(i18n("&Refresh"), this);
     mACollection->addAction(QStringLiteral("update"), action);
-    connect(action, SIGNAL(triggered(bool)), mCalendarView, SLOT(updateView()));
+    connect(action, &QAction::triggered, mCalendarView, QOverload<>::of(&CalendarView::updateView));
 
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~ FILTER ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -396,8 +379,8 @@ void ActionManager::initActions()
     mFilterAction->setToolBarMode(KSelectAction::MenuMode);
     mACollection->addAction(QStringLiteral("filter_select"), mFilterAction);
     mFilterAction->setEditable(false);
-    connect(mFilterAction, SIGNAL(triggered(int)),
-            mCalendarView, SLOT(filterActivated(int)));
+    connect(mFilterAction, QOverload<int>::of(&KSelectAction::triggered),
+            mCalendarView, &CalendarView::filterActivated);
     connect(mCalendarView, &CalendarView::filtersUpdated,
             this, &ActionManager::setItems);
     connect(mCalendarView, &CalendarView::filterChanged,
@@ -532,18 +515,18 @@ void ActionManager::initActions()
 
     mShowIncidenceAction = new QAction(i18n("&Show"), this);
     mACollection->addAction(QStringLiteral("show_incidence"), mShowIncidenceAction);
-    connect(mShowIncidenceAction, SIGNAL(triggered(bool)), mCalendarView,
-            SLOT(showIncidence()));
+    connect(mShowIncidenceAction, &QAction::triggered, mCalendarView,
+            QOverload<>::of(&CalendarView::showIncidence));
 
     mEditIncidenceAction = new QAction(i18n("&Edit..."), this);
     mACollection->addAction(QStringLiteral("edit_incidence"), mEditIncidenceAction);
-    connect(mEditIncidenceAction, SIGNAL(triggered(bool)), mCalendarView,
-            SLOT(editIncidence()));
+    connect(mEditIncidenceAction, &QAction::triggered, mCalendarView,
+            QOverload<>::of(&CalendarView::editIncidence));
 
     mDeleteIncidenceAction = new QAction(i18n("&Delete"), this);
     mACollection->addAction(QStringLiteral("delete_incidence"), mDeleteIncidenceAction);
-    connect(mDeleteIncidenceAction, SIGNAL(triggered(bool)), mCalendarView,
-            SLOT(deleteIncidence()));
+    connect(mDeleteIncidenceAction, &QAction::triggered, mCalendarView,
+            QOverload<>::of(&CalendarView::deleteIncidence));
     mACollection->setDefaultShortcut(mDeleteIncidenceAction, QKeySequence(Qt::Key_Delete));
 
     action = new QAction(i18n("&Make Sub-to-do Independent"), this);
@@ -560,13 +543,14 @@ void ActionManager::initActions()
 //                                         mACollection, "activate_alarm" );
 
     /************************** SCHEDULE MENU ********************************/
-    mPublishEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("&Publish Item Information..."), this);
+    mPublishEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")),
+                                i18n("&Publish Item Information..."), this);
     mACollection->addAction(QStringLiteral("schedule_publish"), mPublishEvent);
     connect(mPublishEvent, SIGNAL(triggered(bool)), mCalendarView, SLOT(schedule_publish()));
     mPublishEvent->setEnabled(false);
 
-    mSendInvitation =
-        new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("Send &Invitation to Attendees"), this);
+    mSendInvitation = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")),
+                                  i18n("Send &Invitation to Attendees"), this);
     mACollection->addAction(QStringLiteral("schedule_request"), mSendInvitation);
     connect(mSendInvitation, SIGNAL(triggered(bool)), mCalendarView, SLOT(schedule_request()));
     mSendInvitation->setEnabled(false);
@@ -587,8 +571,8 @@ void ActionManager::initActions()
     connect(mCalendarView, &CalendarView::organizerEventsSelected,
             mSendCancel, &QAction::setEnabled);
 
-    mSendStatusUpdate =
-        new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("Send Status &Update"), this);
+    mSendStatusUpdate = new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")),
+                                    i18n("Send Status &Update"), this);
     mACollection->addAction(QStringLiteral("schedule_reply"), mSendStatusUpdate);
     connect(mSendStatusUpdate, SIGNAL(triggered(bool)), mCalendarView, SLOT(schedule_reply()));
     mSendStatusUpdate->setEnabled(false);
@@ -607,7 +591,8 @@ void ActionManager::initActions()
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::mailFreeBusy);
     action->setEnabled(true);
 
-    mForwardEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18n("&Send as iCalendar..."), this);
+    mForwardEvent = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")),
+                                i18n("&Send as iCalendar..."), this);
     mACollection->addAction(QStringLiteral("schedule_forward"), mForwardEvent);
     connect(mForwardEvent, SIGNAL(triggered(bool)), mCalendarView, SLOT(schedule_forward()));
     mForwardEvent->setEnabled(false);
@@ -618,7 +603,8 @@ void ActionManager::initActions()
     action->setEnabled(true);
 
     if (!mIsPart) {
-        action = new QAction(QIcon::fromTheme(QStringLiteral("help-contents")), i18n("&Address Book"), this);
+        action = new QAction(QIcon::fromTheme(QStringLiteral("help-contents")),
+                             i18n("&Address Book"), this);
         mACollection->addAction(QStringLiteral("addressbook"), action);
         connect(action, &QAction::triggered, mCalendarView, &CalendarView::openAddressbook);
     }
@@ -628,15 +614,18 @@ void ActionManager::initActions()
     //~~~~~~~~~~~~~~~~~~~~~~~~~~~~ SIDEBAR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     mDateNavigatorShowAction = new KToggleAction(i18n("Show Date Navigator"), this);
     mACollection->addAction(QStringLiteral("show_datenavigator"), mDateNavigatorShowAction);
-    connect(mDateNavigatorShowAction, &KToggleAction::triggered, this, &ActionManager::toggleDateNavigator);
+    connect(mDateNavigatorShowAction, &KToggleAction::triggered,
+            this, &ActionManager::toggleDateNavigator);
 
     mTodoViewShowAction = new KToggleAction(i18n("Show To-do View"), this);
     mACollection->addAction(QStringLiteral("show_todoview"), mTodoViewShowAction);
-    connect(mTodoViewShowAction, &KToggleAction::triggered, this, &ActionManager::toggleTodoView);
+    connect(mTodoViewShowAction, &KToggleAction::triggered,
+            this, &ActionManager::toggleTodoView);
 
     mEventViewerShowAction = new KToggleAction(i18n("Show Item Viewer"), this);
     mACollection->addAction(QStringLiteral("show_eventviewer"), mEventViewerShowAction);
-    connect(mEventViewerShowAction, &KToggleAction::triggered, this, &ActionManager::toggleEventViewer);
+    connect(mEventViewerShowAction, &KToggleAction::triggered,
+            this, &ActionManager::toggleEventViewer);
 
     KConfigGroup config(KSharedConfig::openConfig(), "Settings");
     mDateNavigatorShowAction->setChecked(config.readEntry("DateNavigatorVisible", true));
@@ -653,7 +642,8 @@ void ActionManager::initActions()
     if (!mMainWindow->hasDocument()) {
         mCollectionViewShowAction = new KToggleAction(i18n("Show Calendar Manager"), this);
         mACollection->addAction(QStringLiteral("show_resourceview"), mCollectionViewShowAction);
-        connect(mCollectionViewShowAction, &KToggleAction::triggered, this, &ActionManager::toggleResourceView);
+        connect(mCollectionViewShowAction, &KToggleAction::triggered,
+                this, &ActionManager::toggleResourceView);
         mCollectionViewShowAction->setChecked(config.readEntry("ResourceViewVisible", true));
 
         toggleResourceView();
@@ -666,17 +656,16 @@ void ActionManager::initActions()
 
     action = new QAction(i18n("Configure &Date && Time..."), this);
     mACollection->addAction(QStringLiteral("conf_datetime"), action);
-    connect(action, &QAction::triggered,
-            this, &ActionManager::configureDateTime);
+    connect(action, &QAction::triggered, this, &ActionManager::configureDateTime);
 // TODO: Add an item to show the resource management dlg
 //   new QAction( i18n( "Manage &Calendars..." ), 0,
 //                     this, SLOT(manageResources()),
 //                     mACollection, "conf_resources" );
 
-    action = new QAction(QIcon::fromTheme(QStringLiteral("view-filter")), i18n("Manage View &Filters..."), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("view-filter")),
+                         i18n("Manage View &Filters..."), this);
     mACollection->addAction(QStringLiteral("edit_filters"), action);
-    connect(action, &QAction::triggered, mCalendarView,
-            &CalendarView::editFilters);
+    connect(action, &QAction::triggered, mCalendarView, &CalendarView::editFilters);
 
     action = new QAction(i18n("Manage C&ategories..."), this);
     mACollection->addAction(QStringLiteral("edit_categories"), action);
@@ -684,10 +673,10 @@ void ActionManager::initActions()
             &KODialogManager::showCategoryEditDialog);
 
     if (mIsPart) {
-        action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KOrganizer..."), this);
+        action = new QAction(QIcon::fromTheme(QStringLiteral("configure")),
+                             i18n("&Configure KOrganizer..."), this);
         mACollection->addAction(QStringLiteral("korganizer_configure"), action);
-        connect(action, &QAction::triggered, mCalendarView,
-                &CalendarView::edit_options);
+        connect(action, &QAction::triggered, mCalendarView, &CalendarView::edit_options);
         mACollection->addAction(KStandardAction::KeyBindings, QStringLiteral("korganizer_configure_shortcuts"),
                                 this, SLOT(keyBindings()));
     } else {
@@ -740,9 +729,13 @@ void ActionManager::slotMergeFinished(bool success, int total)
     Akonadi::ICalImporter *importer = qobject_cast<Akonadi::ICalImporter *>(sender());
 
     if (success) {
-        mCalendarView->showMessage(i18np("1 incidence was imported successfully.", "%1 incidences were imported successfully.", total), KMessageWidget::Information);
+        mCalendarView->showMessage(i18np("1 incidence was imported successfully.",
+                                         "%1 incidences were imported successfully.", total),
+                                   KMessageWidget::Information);
     } else {
-        mCalendarView->showMessage(i18n("There was an error while merging the calendar: %1", importer->errorMessage()), KMessageWidget::Error);
+        mCalendarView->showMessage(i18n("There was an error while merging the calendar: %1",
+                                        importer->errorMessage()),
+                                   KMessageWidget::Error);
     }
 }
 
@@ -752,9 +745,12 @@ void ActionManager::slotNewResourceFinished(bool success)
     Akonadi::ICalImporter *importer = qobject_cast<Akonadi::ICalImporter *>(sender());
     mImportAction->setEnabled(true);
     if (success) {
-        mCalendarView->showMessage(i18n("New calendar added successfully"), KMessageWidget::Information);
+        mCalendarView->showMessage(i18n("New calendar added successfully"),
+                                   KMessageWidget::Information);
     } else {
-        mCalendarView->showMessage(i18n("Could not add a calendar. Error: %1", importer->errorMessage()), KMessageWidget::Error);
+        mCalendarView->showMessage(i18n("Could not add a calendar. Error: %1",
+                                        importer->errorMessage()),
+                                   KMessageWidget::Error);
     }
     sender()->deleteLater();
 }
@@ -808,18 +804,21 @@ void ActionManager::writeSettings()
 
 void ActionManager::file_open()
 {
-    const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/korganizer/");
-    const QUrl url = QFileDialog::getOpenFileUrl(dialogParent(), QString(), QUrl::fromLocalFile(defaultPath), QStringLiteral("text/calendar"));
+    const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
+    const QUrl dir = QUrl::fromLocalFile(defaultPath + QLatin1String("/korganizer/"));
+    const QUrl url = QFileDialog::getOpenFileUrl(
+        dialogParent(),
+        i18nc("@title:window", "Select Calendar File to Open"),
+        dir,
+        QStringLiteral("text/calendar (*.ics *.vcs)"));
 
-    file_open(url);
+    if (!url.isEmpty()){   // isEmpty if user canceled the dialog
+        file_open(url);
+    }
 }
 
 void ActionManager::file_open(const QUrl &url)
 {
-    if (url.isEmpty()) {
-        return;
-    }
-
     // is that URL already opened somewhere else? Activate that window
     KOrg::MainWindow *korg = ActionManager::findInstance(url);
     if ((nullptr != korg) && (korg != mMainWindow)) {
@@ -834,54 +833,16 @@ void ActionManager::file_open(const QUrl &url)
     importCalendar(url);
 }
 
-void ActionManager::file_icalimport()
-{
-    // FIXME: eventually, we will need a dialog box to select import type, etc.
-    // for now, hard-coded to ical file, $HOME/.calendar.
-    int retVal = -1;
-    QTemporaryFile tmpfn;
-    tmpfn.open();
-
-    QString homeDir = QDir::homePath() + QLatin1String("/.calendar");
-
-    if (!QFileInfo::exists(homeDir)) {
-        KMessageBox::error(dialogParent(),
-                           i18n("You have no ical file in your home directory.\n"
-                                "Import cannot proceed.\n"));
-        return;
-    }
-
-    KProcess proc;
-    proc << QStringLiteral("ical2vcal") << tmpfn.fileName();
-    retVal = proc.execute();
-
-    qCDebug(KORGANIZER_LOG) << "ical2vcal return value:" << retVal;
-
-    if (retVal >= 0 && retVal <= 2) {
-        // now we need to MERGE what is in the iCal to the current calendar.
-        const bool success = importURL(QUrl::fromLocalFile(tmpfn.fileName()), /*merge=*/ true);
-        if (!success) {
-            mCalendarView->showMessage(i18n("KOrganizer encountered some unknown fields while "
-                                            "parsing your .calendar ical file, and had to "
-                                            "discard them; please check to see that all "
-                                            "your relevant data was correctly imported."), KMessageWidget::Warning);
-
-        } else {
-            // else nothing, the operation is async and the use will se a message widget when the operation finishes, not now.
-        }
-    } else if (retVal == -1) {   // XXX this is bogus
-        mCalendarView->showMessage(i18n("KOrganizer encountered an error parsing your "
-                                        ".calendar file from ical; import has failed."), KMessageWidget::Error);
-    } else if (retVal == -2) {   // XXX this is bogus
-        mCalendarView->showMessage(i18n("KOrganizer does not think that your .calendar "
-                                        "file is a valid ical calendar; import has failed."), KMessageWidget::Error);
-    }
-}
-
 void ActionManager::file_import()
 {
-    const QUrl url = QFileDialog::getOpenFileUrl(dialogParent(), QString(), QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/korganizer/")),
-                     QStringLiteral("text/calendar"));
+    const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
+    const QUrl dir = QUrl::fromLocalFile(defaultPath + QLatin1String("/korganizer/"));
+    const QUrl url = QFileDialog::getOpenFileUrl(
+            dialogParent(),
+            i18nc("@title:window", "Select Calendar File to Import"),
+            dir,
+            QStringLiteral("text/calendar (*.ics *.vcs)"));
+
     if (!url.isEmpty()) {   // isEmpty if user canceled the dialog
         importCalendar(url);
     }
@@ -926,28 +887,6 @@ bool ActionManager::saveURL()
         ext = mURL.fileName().right(4);
     }
 
-    if (ext == QLatin1String(".vcs")) {
-        int result = KMessageBox::warningContinueCancel(
-                         dialogParent(),
-                         i18n("Your calendar will be saved in iCalendar format. Use "
-                              "'Export vCalendar' to save in vCalendar format."),
-                         i18n("Format Conversion"), KGuiItem(i18n("Proceed")),
-                         KStandardGuiItem::cancel(),
-                         QStringLiteral("dontaskFormatConversion"), KMessageBox::Notify);
-        if (result != KMessageBox::Continue) {
-            return false;
-        }
-
-        QString filename = mURL.fileName();
-        filename.replace(filename.length() - 4, 4, QStringLiteral(".ics"));
-        mURL = mURL.adjusted(QUrl::RemoveFilename);
-        mURL.setPath(mURL.path() + filename);
-        if (mURL.isLocalFile()) {
-            mFile = mURL.toLocalFile();
-        }
-        setTitle();
-    }
-
     if (!mCalendarView->saveCalendar(mFile)) {
         qCDebug(KORGANIZER_LOG) << "calendar view save failed.";
         return false;
@@ -1014,35 +953,8 @@ bool ActionManager::saveAsURL(const QUrl &url)
     return success;
 }
 
-QUrl ActionManager::getSaveURL()
-{
-    QUrl url =
-        QFileDialog::getSaveFileUrl(dialogParent(), QString(), QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/korganizer/")),
-                                    i18n("*.ics *.vcs|Calendar Files")
-                                   );
-
-    if (!url.isValid()) {
-        return url;
-    }
-
-    QString filename = url.fileName();
-
-    QString e = filename.right(4);
-    if (e != QLatin1String(".vcs") && e != QLatin1String(".ics")) {
-        // Default save format is iCalendar
-        filename += QLatin1String(".ics");
-    }
-    url = url.adjusted(QUrl::RemoveFilename);
-    url.setPath(url.path() + filename);
-
-    qCDebug(KORGANIZER_LOG) << "url:" << url.url();
-
-    return url;
-}
-
 void ActionManager::saveProperties(KConfigGroup &config)
 {
-
     config.writeEntry("UseResourceCalendar", !mMainWindow->hasDocument());
     if (mMainWindow->hasDocument()) {
         config.writePathEntry("Calendar", mURL.url());
@@ -1057,7 +969,6 @@ void ActionManager::readProperties(const KConfigGroup &)
 // Configuration changed as a result of the options dialog.
 void ActionManager::updateConfig()
 {
-
     mNextXDays->setText(i18np("&Next Day", "&Next %1 Days",
                               KOPrefs::instance()->mNextXDays));
 
@@ -1082,7 +993,10 @@ void ActionManager::updateConfig()
 void ActionManager::configureDateTime()
 {
     KProcess proc;
-    proc << QStringLiteral("kcmshell5") << QStringLiteral("formats") << QStringLiteral("translations") << QStringLiteral("clock");
+    proc << QStringLiteral("kcmshell5")
+         << QStringLiteral("formats")
+         << QStringLiteral("translations")
+         << QStringLiteral("clock");
 
     if (!proc.startDetached()) {
         KMessageBox::sorry(dialogParent(),
@@ -1231,10 +1145,9 @@ bool ActionManager::addIncidence(const QString &ical)
 
 void ActionManager::downloadNewStuff()
 {
-
-    KNS3::DownloadDialog dialog(mCalendarView);
-    dialog.exec();
-    foreach (const KNS3::Entry &e, dialog.installedEntries()) {
+    QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog(mCalendarView);
+    dialog->exec();
+    foreach (const KNS3::Entry &e, dialog->installedEntries()) {
         qCDebug(KORGANIZER_LOG) << " downloadNewStuff :";
         const QStringList lstFile = e.installedFiles();
         if (lstFile.count() != 1) {
@@ -1273,6 +1186,7 @@ void ActionManager::downloadNewStuff()
             }
         }
     }
+    delete dialog;
 }
 
 QString ActionManager::localFileName()
@@ -1348,9 +1262,9 @@ protected:
         }
         return true;
     }
-    QAction *mShow;
-    QAction *mEdit;
-    QAction *mDelete;
+    QAction *mShow = nullptr;
+    QAction *mEdit = nullptr;
+    QAction *mDelete = nullptr;
 };
 
 void ActionManager::processIncidenceSelection(const Akonadi::Item &item, const QDate &date)
@@ -1782,4 +1696,3 @@ void ActionManager::setHelpText(QAction *act, const QString &text)
         act->setWhatsThis(text);
     }
 }
-
