@@ -37,9 +37,7 @@
 #include <QTimer>
 
 DateNavigatorContainer::DateNavigatorContainer(QWidget *parent)
-    : QFrame(parent),
-      mHorizontalCount(1), mVerticalCount(1),
-      mIgnoreNavigatorUpdates(false)
+    : QFrame(parent)
 {
     mNavigatorView = new KDateNavigator(this);
     mNavigatorView->setWhatsThis(
@@ -258,11 +256,14 @@ void DateNavigatorContainer::resizeAllContents()
 
         mHorizontalCount = horizontalCount;
         mVerticalCount = verticalCount;
-        setBaseDates(mNavigatorView->selectedDates().first());
-        selectDates(mNavigatorView->selectedDates());
-        for (KDateNavigator *n : qAsConst(mExtraViews)) {
-            if (n) {
-                n->show();
+        const KCalCore::DateList dates = mNavigatorView->selectedDates();
+        if (!dates.isEmpty()) {
+            setBaseDates(dates.first());
+            selectDates(dates);
+            for (KDateNavigator *n : qAsConst(mExtraViews)) {
+                if (n) {
+                    n->show();
+                }
             }
         }
     }
@@ -423,4 +424,3 @@ KDateNavigator *DateNavigatorContainer::firstNavigatorForDate(const QDate &date)
 
     return navigator;
 }
-
