@@ -154,16 +154,16 @@ private:
      */
     KDateNavigator *firstNavigatorForDate(const QDate &date) const;
 
-    KDateNavigator *mNavigatorView;
+    KDateNavigator *mNavigatorView = nullptr;
 
     Akonadi::ETMCalendar::Ptr mCalendar;
 
     QList<KDateNavigator *> mExtraViews;
 
-    int mHorizontalCount;
-    int mVerticalCount;
+    int mHorizontalCount = 1;
+    int mVerticalCount = 1;
 
-    bool mIgnoreNavigatorUpdates;
+    bool mIgnoreNavigatorUpdates = false;
 };
 
 #endif
