@@ -62,10 +62,6 @@ public Q_SLOTS:
         updateView();
     }
 
-protected Q_SLOTS:
-    void doSearch();
-    void searchTextChanged(const QString &_text);
-
 Q_SIGNALS:
     void showIncidenceSignal(const Akonadi::Item &);
     void editIncidenceSignal(const Akonadi::Item &);
@@ -75,16 +71,18 @@ protected:
     /*reimp*/
     void showEvent(QShowEvent *event) override;
 private:
+    void doSearch();
+    void searchTextChanged(const QString &_text);
     void slotHelpRequested();
     void search(const QRegExp &);
     void readConfig();
     void writeConfig();
 
-    Ui::SearchDialog *m_ui;
-    CalendarView *m_calendarview; // parent
+    Ui::SearchDialog *m_ui = nullptr;
+    CalendarView *m_calendarview = nullptr; // parent
     Akonadi::Item::List mMatchedEvents;
-    EventViews::ListView *listView;
-    QPushButton *mUser1Button;
+    EventViews::ListView *listView = nullptr;
+    QPushButton *mUser1Button = nullptr;
 };
 
 #endif
