@@ -28,13 +28,12 @@
 #include "actionmanager.h"
 #include "calendarview.h"
 #include "korganizer.h"
-#include "KdepimDBusInterfaces/ReminderClient"
 #include "korganizer-version.h"
 #include <KCalCore/CalFormat>
+#include "KdepimDBusInterfaces/ReminderClient"
 
 #include "korganizer_debug.h"
 #include "korganizer_options.h"
-#include <KStartupInfo>
 #include <QCommandLineParser>
 
 KOrganizerApp::KOrganizerApp(int &argc, char **argv[])
@@ -84,15 +83,18 @@ int KOrganizerApp::activate(const QStringList &args, const QString &workingDir)
     }
     // Check for import, merge or ask
     if (parser.isSet(QStringLiteral("import"))) {
-        for (const QString &url : parser.positionalArguments()) {
+        // Q_FOREACH, since range-based loops might detach Qt container (QStringList)
+        Q_FOREACH (const QString &url, parser.positionalArguments()) {
             korg->actionManager()->importURL(QUrl::fromUserInput(url), false);
         }
     } else if (parser.isSet(QStringLiteral("merge"))) {
-        for (const QString &url : parser.positionalArguments()) {
+        // Q_FOREACH, since range-based loops might detach Qt container (QStringList)
+        Q_FOREACH (const QString &url, parser.positionalArguments()) {
             korg->actionManager()->importURL(QUrl::fromUserInput(url), true);
         }
     } else {
-        for (const QString &url : parser.positionalArguments()) {
+        // Q_FOREACH, since range-based loops might detach Qt container (QStringList)
+        Q_FOREACH (const QString &url, parser.positionalArguments()) {
             korg->actionManager()->importCalendar(QUrl::fromUserInput(url));
         }
     }
