@@ -276,7 +276,7 @@ void KODayMatrix::updateJournals()
 
     for (const KCalCore::Incidence::Ptr &inc : incidences) {
         Q_ASSERT(inc);
-        QDate d = inc->dtStart().toTimeSpec(mCalendar->timeSpec()).date();
+        QDate d = inc->dtStart().toLocalTime().date();
         if (inc->type() == KCalCore::Incidence::TypeJournal &&
                 d >= mDays[0] &&
                 d <= mDays[NUMDAYS - 1] &&
@@ -294,7 +294,7 @@ void KODayMatrix::updateJournals()
   * Although updateTodos() is simpler it has some similarities with updateEvent()
   * but don't bother refactoring them so they share code, there's a bigger fish:
   * Try to refactor updateTodos(), updateEvent(), updateJournals(), monthview,
-  * agenda view, timespent view, timeline view, event list view and todo list view
+  * agenda view, timeline view, event list view and todo list view
   * all these 9 places have incidence listing code in common, maybe it could go
   * to kcal. Ah, and then there's kontact's summary view which still uses
   * the old CPU consuming code.
@@ -317,20 +317,20 @@ void KODayMatrix::updateTodos()
                     !(recurType == KCalCore::Recurrence::rWeekly && !KOPrefs::instance()->mWeeklyRecur)) {
 
                 // It's a recurring todo, find out in which days it occurs
-                const KCalCore::DateTimeList timeDateList =
+                const auto timeDateList =
                     t->recurrence()->timesInInterval(
-                        KDateTime(mDays[0], mCalendar->timeSpec()),
-                        KDateTime(mDays[NUMDAYS - 1], mCalendar->timeSpec()));
+                        QDateTime(mDays[0], {}, Qt::LocalTime),
+                        QDateTime(mDays[NUMDAYS - 1], {}, Qt::LocalTime));
 
-                for (const KDateTime &dt : timeDateList) {
-                    d = dt.toTimeSpec(mCalendar->timeSpec()).date();
+                for (const QDateTime &dt : timeDateList) {
+                    d = dt.toLocalTime().date();
                     if (!mEvents.contains(d)) {
                         mEvents.append(d);
                     }
                 }
 
             } else {
-                d = t->dtDue().toTimeSpec(mCalendar->timeSpec()).date();
+                d = t->dtDue().toLocalTime().date();
                 if (d >= mDays[0] && d <= mDays[NUMDAYS - 1] && !mEvents.contains(d)) {
                     mEvents.append(d);
                 }
@@ -347,7 +347,7 @@ void KODayMatrix::updateEvents()
         return;
     }
     const KCalCore::Event::List eventlist = mCalendar->events(mDays[0], mDays[NUMDAYS - 1],
-                                      mCalendar->timeSpec());
+                                      mCalendar->timeZone());
 
     for (const KCalCore::Event::Ptr &event : eventlist) {
         if (mEvents.count() == NUMDAYS) {
@@ -357,39 +357,38 @@ void KODayMatrix::updateEvents()
 
         Q_ASSERT(event);
         const ushort recurType = event->recurrenceType();
-        const KDateTime dtStart = event->dtStart().toTimeSpec(mCalendar->timeSpec());
+        const QDateTime dtStart = event->dtStart().toLocalTime();
 
         // timed incidences occur in
         //   [dtStart(), dtEnd()[. All-day incidences occur in [dtStart(), dtEnd()]
         // so we subtract 1 second in the timed case
         const int secsToAdd = event->allDay() ? 0 : -1;
-        const KDateTime dtEnd = event->dtEnd().toTimeSpec(mCalendar->timeSpec()).addSecs(secsToAdd);
+        const QDateTime dtEnd = event->dtEnd().toLocalTime().addSecs(secsToAdd);
 
         if (!(recurType == KCalCore::Recurrence::rDaily  && !KOPrefs::instance()->mDailyRecur) &&
                 !(recurType == KCalCore::Recurrence::rWeekly && !KOPrefs::instance()->mWeeklyRecur)) {
 
-            KCalCore::DateTimeList timeDateList;
+            KCalCore::SortableList<QDateTime> timeDateList;
             const bool isRecurrent = event->recurs();
             const int eventDuration = dtStart.daysTo(dtEnd);
 
             if (isRecurrent) {
                 //Its a recurring event, find out in which days it occurs
                 timeDateList = event->recurrence()->timesInInterval(
-                                   KDateTime(mDays[0], mCalendar->timeSpec()),
-                                   KDateTime(mDays[NUMDAYS - 1], mCalendar->timeSpec()));
+                                   QDateTime(mDays[0], {}, Qt::LocalTime),
+                                   QDateTime(mDays[NUMDAYS - 1], {}, Qt::LocalTime));
             } else {
                 if (dtStart.date() >= mDays[0]) {
                     timeDateList.append(dtStart);
                 } else {
                     // The event starts in another month (not visible))
-                    timeDateList.append(KDateTime(mDays[0], mCalendar->timeSpec()));
+                    timeDateList.append(QDateTime(mDays[0], {}, Qt::LocalTime));
                 }
             }
 
-            KCalCore::DateTimeList::iterator t;
-            for (t = timeDateList.begin(); t != timeDateList.end(); ++t) {
+            for (auto t = timeDateList.begin(); t != timeDateList.end(); ++t) {
                 //This could be a multiday event, so iterate from dtStart() to dtEnd()
-                QDate d = t->toTimeSpec(mCalendar->timeSpec()).date();
+                QDate d = t->toLocalTime().date();
                 int j   = 0;
 
                 QDate occurrenceEnd;
@@ -719,7 +718,6 @@ void KODayMatrix::paintEvent(QPaintEvent *)
     const int dayHeight = mDaySize.height();
     const int dayWidth = mDaySize.width();
     int row, column;
-    int selectionWidth, selectionHeight;
     const bool isRTL = KOGlobals::self()->reverseLayout();
 
     QPalette pal = palette();
@@ -759,7 +757,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
                 p.fillRect(isRTL ? 0 : column * dayWidth, row * dayHeight,
                            (7 - column) * dayWidth, dayHeight, selectionColor);
                 // draw full block till last line
-                selectionHeight = mSelEnd / 7 - row;
+                int selectionHeight = mSelEnd / 7 - row;
                 if (selectionHeight + row >= 6) {
                     selectionHeight = 6 - row;
                 }
@@ -769,7 +767,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
                 }
                 // draw last block from left to mSelEnd
                 if (mSelEnd / 7 < 6) {
-                    selectionWidth = mSelEnd - 7 * (mSelEnd / 7) + 1;
+                    int selectionWidth = mSelEnd - 7 * (mSelEnd / 7) + 1;
                     p.fillRect(isRTL ?
                                (7 - selectionWidth) * dayWidth :
                                0,
