@@ -44,7 +44,6 @@
 #include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KSystemTimeZone>
 #include <QTemporaryFile>
 
 #include <QDropEvent>
@@ -120,7 +119,6 @@ QStringList TodoPlugin::invisibleToolbarActions() const
     invisible += QStringLiteral("view_todo");
     invisible += QStringLiteral("view_journal");
     invisible += QStringLiteral("view_timeline");
-    invisible += QStringLiteral("view_timespent");
 
     return invisible;
 }
@@ -191,7 +189,7 @@ void TodoPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (KCalUtils::ICalDrag::canDecode(event->mimeData())) {
-        KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(KSystemTimeZones::local()));
+        KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         if (KCalUtils::ICalDrag::fromMimeData(event->mimeData(), cal)) {
             KCalCore::Incidence::List incidences = cal->incidences();
             Q_ASSERT(incidences.count());
