@@ -41,10 +41,10 @@
 
 #include <QMenu>
 #include <KLocalizedString>
-#include <KLocale>
 #include <KUrlLabel>
 #include <KIconLoader>
 #include <KConfigGroup>
+#include <KConfig>
 #include <QDesktopServices>
 #include <KHolidays/HolidayRegion>
 
@@ -118,9 +118,9 @@ SDSummaryWidget::SDSummaryWidget(KontactInterface::Plugin *plugin, QWidget *pare
     mainLayout->setSpacing(3);
     mainLayout->setMargin(3);
 
-    //TODO: we want our own special dates icon
-    QWidget *header = createHeader(
-                          this, QStringLiteral("favorites"), i18n("Upcoming Special Dates"));
+    QWidget *header = createHeader(this,
+                                   QStringLiteral("view-calendar-special-occasion"),
+                                   i18n("Upcoming Special Dates"));
     mainLayout->addWidget(header);
 
     mLayout = new QGridLayout();
@@ -144,8 +144,6 @@ SDSummaryWidget::SDSummaryWidget(KontactInterface::Plugin *plugin, QWidget *pare
 
     connect(mCalendar.data(), &Akonadi::ETMCalendar::calendarChanged,
             this, &SDSummaryWidget::updateView);
-    connect(mPlugin->core(), &KontactInterface::Core::dayChanged,
-            this, &SDSummaryWidget::updateView);
 
     // Update Configuration
     configUpdated();
@@ -230,7 +228,7 @@ int SDSummaryWidget::dayof(const KCalCore::Event::Ptr &event, const QDate &date)
 void SDSummaryWidget::slotBirthdayJobFinished(KJob *job)
 {
     // ;)
-    BirthdaySearchJob *bJob = qobject_cast< BirthdaySearchJob *>(job);
+    BirthdaySearchJob *bJob = qobject_cast<BirthdaySearchJob *>(job);
     if (bJob) {
         foreach (const Akonadi::Item &item, bJob->items()) {
             if (item.hasPayload<KContacts::Addressee>()) {
@@ -276,9 +274,9 @@ void SDSummaryWidget::createLabels()
 
     QDate dt;
     for (dt = QDate::currentDate();
-            dt <= QDate::currentDate().addDays(mDaysAhead - 1);
-            dt = dt.addDays(1)) {
-        const KCalCore::Event::List events  = mCalendar->events(dt, mCalendar->timeSpec(),
+         dt <= QDate::currentDate().addDays(mDaysAhead - 1);
+         dt = dt.addDays(1)) {
+        const KCalCore::Event::List events  = mCalendar->events(dt, mCalendar->timeZone(),
                                         KCalCore::EventSortStartDate,
                                         KCalCore::SortDirectionAscending);
         for (const KCalCore::Event::Ptr &ev : events) {
@@ -386,8 +384,8 @@ void SDSummaryWidget::createLabels()
     if (mShowHolidays) {
         if (initHolidays()) {
             for (dt = QDate::currentDate();
-                    dt <= QDate::currentDate().addDays(mDaysAhead - 1);
-                    dt = dt.addDays(1)) {
+                 dt <= QDate::currentDate().addDays(mDaysAhead - 1);
+                 dt = dt.addDays(1)) {
                 QList<Holiday> holidays = mHolidays->holidays(dt);
                 QList<Holiday>::ConstIterator it = holidays.constBegin();
                 for (; it != holidays.constEnd(); ++it) {
@@ -450,7 +448,7 @@ void SDSummaryWidget::createLabels()
                 icon_name = QStringLiteral("view-calendar-holiday");
                 break;
             case CategoryOther:
-                icon_name = QStringLiteral("favorites");
+                icon_name = QStringLiteral("view-calendar-special-occasion");
                 break;
             }
             label = new QLabel(this);
@@ -476,13 +474,21 @@ void SDSummaryWidget::createLabels()
             } else if ((*addrIt).daysTo == 1) {
                 datestr = i18nc("the special day is tomorrow", "Tomorrow");
             } else {
-                datestr = KLocale::global()->formatDate(sD, KLocale::FancyLongDate);
+                const auto locale = QLocale::system();
+                for (int i = 3; i < 8; ++i) {
+                    if ((*addrIt).daysTo < i) {
+                        datestr = locale.dayName(sD.dayOfWeek(), QLocale::LongFormat);
+                        break;
+                    }
+                }
+                if (datestr.isEmpty()) {
+                    datestr = locale.toString(sD, QLocale::ShortFormat);
+                }
             }
             // Print the date span for multiday, floating events, for the
             // first day of the event only.
             if ((*addrIt).span > 1) {
-                QString endstr =
-                    KLocale::global()->formatDate(sD.addDays((*addrIt).span - 1));
+                QString endstr = QLocale::system().toString(sD.addDays((*addrIt).span - 1), QLocale::LongFormat);
                 datestr += QLatin1String(" -\n ") + endstr;
             }
 
@@ -541,8 +547,10 @@ void SDSummaryWidget::createLabels()
                 mLayout->addWidget(urlLabel, counter, 4);
                 mLabels.append(urlLabel);
 
-                connect(urlLabel, static_cast<void (KUrlLabel::*)(const QString &)>(&KUrlLabel::leftClickedUrl), this, &SDSummaryWidget::mailContact);
-                connect(urlLabel, static_cast<void (KUrlLabel::*)(const QString &)>(&KUrlLabel::rightClickedUrl), this, &SDSummaryWidget::popupMenu);
+                connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::leftClickedUrl),
+                        this, &SDSummaryWidget::mailContact);
+                connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::rightClickedUrl),
+                        this, &SDSummaryWidget::popupMenu);
             } else {
                 label = new QLabel(this);
                 label->setText((*addrIt).summary);
@@ -658,20 +666,21 @@ void SDSummaryWidget::viewContact(const QString &url)
         return;
     }
 
-    Akonadi::ContactViewerDialog dlg(this);
-    dlg.setContact(item);
-    dlg.exec();
+    QPointer<Akonadi::ContactViewerDialog> dlg = new Akonadi::ContactViewerDialog(this);
+    dlg->setContact(item);
+    dlg->exec();
+    delete dlg;
 }
 
 void SDSummaryWidget::popupMenu(const QString &url)
 {
     QMenu popup(this);
-    const QAction *sendMailAction = popup.addAction(
-                                        KIconLoader::global()->loadIcon(QStringLiteral("mail-message-new"), KIconLoader::Small),
-                                        i18n("Send &Mail"));
-    const QAction *viewContactAction = popup.addAction(
-                                           KIconLoader::global()->loadIcon(QStringLiteral("view-pim-contacts"), KIconLoader::Small),
-                                           i18n("View &Contact"));
+    const QAction *sendMailAction =
+        popup.addAction(KIconLoader::global()->loadIcon(QStringLiteral("mail-message-new"), KIconLoader::Small),
+                        i18n("Send &Mail"));
+    const QAction *viewContactAction =
+        popup.addAction(KIconLoader::global()->loadIcon(QStringLiteral("view-pim-contacts"), KIconLoader::Small),
+                        i18n("View &Contact"));
 
     const QAction *ret = popup.exec(QCursor::pos());
     if (ret == sendMailAction) {
