@@ -37,7 +37,6 @@
 #include "views/monthview/monthview.h"
 #include "views/multiagendaview/multiagendaview.h"
 #include "views/timelineview/kotimelineview.h"
-#include "views/timespentview/kotimespentview.h"
 #include "views/todoview/kotodoview.h"
 #include "views/whatsnextview/kowhatsnextview.h"
 
@@ -63,7 +62,6 @@ KOViewManager::KOViewManager(CalendarView *mainView)
     mTimelineView = nullptr;
     mAgendaViewTabs = nullptr;
     mAgendaViewTabIndex = 0;
-    mTimeSpentView = nullptr;
     mMonthView = nullptr;
     mRangeMode = NO_RANGE;
 }
@@ -96,8 +94,6 @@ void KOViewManager::readSettings(KConfig *config)
         showTodoView();
     } else if (view == QLatin1String("Timeline")) {
         showTimeLineView();
-    } else if (view == QLatin1String("TimeSpent")) {
-        showTimeSpentView();
     } else if (view == QLatin1String("Month")) {
         showMonthView();
     } else {
@@ -140,8 +136,6 @@ void KOViewManager::writeSettings(KConfig *config)
         view = QStringLiteral("Todo");
     } else if (mCurrentView == mTimelineView) {
         view = QStringLiteral("Timeline");
-    } else if (mCurrentView == mTimeSpentView) {
-        view = QStringLiteral("TimeSpent");
     } else if (mCurrentView == mMonthView) {
         view = QStringLiteral("Month");
     } else {
@@ -229,8 +223,7 @@ void KOViewManager::goMenu(bool enable)
     if (w) {
         KActionCollection *ac = w->getActionCollection();
         if (ac) {
-            QAction *action;
-            action = ac->action(QStringLiteral("go_today"));
+            QAction *action = ac->action(QStringLiteral("go_today"));
             if (action) {
                 action->setEnabled(enable);
             }
@@ -272,7 +265,7 @@ void KOViewManager::updateView()
 void KOViewManager::updateView(const QDate &start, const QDate &end, const QDate &preferredMonth)
 {
     if (mCurrentView && mCurrentView != mTodoView) {
-        mCurrentView->setDateRange(KDateTime(start), KDateTime(end), preferredMonth);
+        mCurrentView->setDateRange(QDateTime(start), QDateTime(end), preferredMonth);
     } else if (mTodoView) {
         mTodoView->updateView();
     }
@@ -408,18 +401,6 @@ void KOViewManager::addView(KOrg::BaseView *view, bool isTab)
     }
 }
 
-void KOViewManager::showTimeSpentView()
-{
-    if (!mTimeSpentView) {
-        mTimeSpentView = new KOTimeSpentView(mMainView->viewStack());
-        mTimeSpentView->setCalendar(mMainView->calendar());
-        mTimeSpentView->setIdentifier("DefaultTimeSpentView");
-        addView(mTimeSpentView);
-    }
-    goMenu(true);
-    showView(mTimeSpentView);
-}
-
 void KOViewManager::showMonthView()
 {
     if (!mMonthView) {
@@ -470,8 +451,8 @@ void KOViewManager::showAgendaView()
     if (showBoth) {
         if (!mAgendaViewTabs && showBoth) {
             mAgendaViewTabs = new QTabWidget(mMainView->viewStack());
-            connect(mAgendaViewTabs, SIGNAL(currentChanged(int)),
-                    this, SLOT(currentAgendaViewTabChanged(int)));
+            connect(mAgendaViewTabs, &QTabWidget::currentChanged,
+                    this, &KOViewManager::currentAgendaViewTabChanged);
             mMainView->viewStack()->addWidget(mAgendaViewTabs);
 
             KConfigGroup viewConfig = KSharedConfig::openConfig()->group(QStringLiteral("Views"));
