@@ -38,7 +38,6 @@ class KOAgendaView;
 class KOJournalView;
 class KOListView;
 class KOTimelineView;
-class KOTimeSpentView;
 class KOTodoView;
 class KOWhatsNextView;
 namespace KOrg
@@ -157,7 +156,6 @@ public Q_SLOTS:
     void showAgendaView();
     void showTodoView();
     void showTimeLineView();
-    void showTimeSpentView();
     void showMonthView();
     void showJournalView();
     void showEventView();
@@ -187,21 +185,20 @@ private Q_SLOTS:
 private:
     QWidget *widgetForView(KOrg::BaseView *) const;
     QList<KOrg::BaseView *> mViews;
-    CalendarView *mMainView;
+    CalendarView *mMainView = nullptr;
 
-    KOAgendaView *mAgendaView;
-    KOrg::MultiAgendaView *mAgendaSideBySideView;
-    KOListView *mListView;
-    KOTodoView *mTodoView;
-    KOWhatsNextView *mWhatsNextView;
-    KOJournalView *mJournalView;
-    KOTimelineView *mTimelineView;
-    KOTimeSpentView *mTimeSpentView;
-    KOrg::MonthView *mMonthView;
-    KOrg::BaseView *mCurrentView;
+    KOAgendaView *mAgendaView = nullptr;
+    KOrg::MultiAgendaView *mAgendaSideBySideView = nullptr;
+    KOListView *mListView = nullptr;
+    KOTodoView *mTodoView = nullptr;
+    KOWhatsNextView *mWhatsNextView = nullptr;
+    KOJournalView *mJournalView = nullptr;
+    KOTimelineView *mTimelineView = nullptr;
+    KOrg::MonthView *mMonthView = nullptr;
+    KOrg::BaseView *mCurrentView = nullptr;
 
-    KOrg::BaseView *mLastEventView;
-    QTabWidget *mAgendaViewTabs;
+    KOrg::BaseView *mLastEventView = nullptr;
+    QTabWidget *mAgendaViewTabs = nullptr;
     int mAgendaViewTabIndex;
 
     RangeMode mRangeMode;
