@@ -253,7 +253,7 @@ public:
 
         mHolidayCombo = new KComboBox(holidayRegBox);
         holidayRegBoxHBoxLayout->addWidget(mHolidayCombo);
-        connect(mHolidayCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &KOPrefsDialogMain::slotWidChanged);
+        connect(mHolidayCombo, QOverload<int>::of(&KComboBox::activated), this, &KOPrefsDialogMain::slotWidChanged);
 
         mHolidayCombo->setWhatsThis(KOPrefs::instance()->holidaysItem()->whatsThis());
 
@@ -378,7 +378,7 @@ public:
             CalendarSupport::KCalPrefs::instance()->reminderTimeItem()->whatsThis());
         mReminderTimeSpin->setToolTip(
             CalendarSupport::KCalPrefs::instance()->reminderTimeItem()->toolTip());
-        connect(mReminderTimeSpin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KOPrefsDialogMain::slotWidChanged);
+        connect(mReminderTimeSpin, QOverload<int>::of(&QSpinBox::valueChanged), this, &KOPrefsDialogMain::slotWidChanged);
         remindersLayout->addWidget(mReminderTimeSpin, 0, 1);
 
         mReminderUnitsCombo = new KComboBox(defaultPage);
@@ -386,7 +386,7 @@ public:
             CalendarSupport::KCalPrefs::instance()->reminderTimeUnitsItem()->toolTip());
         mReminderUnitsCombo->setWhatsThis(
             CalendarSupport::KCalPrefs::instance()->reminderTimeUnitsItem()->whatsThis());
-        connect(mReminderUnitsCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &KOPrefsDialogMain::slotWidChanged);
+        connect(mReminderUnitsCombo, QOverload<int>::of(&KComboBox::activated), this, &KOPrefsDialogMain::slotWidChanged);
         mReminderUnitsCombo->addItem(
             i18nc("@item:inlistbox reminder units in minutes", "minute(s)"));
         mReminderUnitsCombo->addItem(
@@ -468,7 +468,8 @@ protected:
                 combo->setCurrentIndex(i);
             }
         } else {
-            for (int i = 0; i < combo->count(); ++i) {
+            const int numberOfElements{combo->count()};
+            for (int i = 0; i < numberOfElements; ++i) {
                 if (combo->itemText(i) == text) {
                     combo->setCurrentIndex(i);
                     break;
@@ -479,9 +480,9 @@ protected:
 
 private:
     QStringList   tzonenames;
-    KComboBox    *mHolidayCombo;
-    QSpinBox  *mReminderTimeSpin;
-    KComboBox    *mReminderUnitsCombo;
+    KComboBox    *mHolidayCombo = nullptr;
+    QSpinBox  *mReminderTimeSpin = nullptr;
+    KComboBox    *mReminderUnitsCombo = nullptr;
     QCheckBox    *mWorkDays[7];
 };
 
@@ -779,7 +780,7 @@ KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts(QWidget *parent)
               "Select here the event category you want to modify. "
               "You can change the selected category color using "
               "the button below."));
-    connect(mCategoryCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &KOPrefsDialogColorsAndFonts::updateCategoryColor);
+    connect(mCategoryCombo, QOverload<int>::of(&KComboBox::activated), this, &KOPrefsDialogColorsAndFonts::updateCategoryColor);
     categoryLayout->addWidget(mCategoryCombo, 1, 0);
 
     mCategoryButton = new KColorButton(categoryGroup);
@@ -812,7 +813,7 @@ KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts(QWidget *parent)
               "Select the calendar you want to modify. "
               "You can change the selected calendar color using "
               "the button below."));
-    connect(mResourceCombo, static_cast<void (Akonadi::CollectionComboBox::*)(int)>(&Akonadi::CollectionComboBox::activated), this, &KOPrefsDialogColorsAndFonts::updateResourceColor);
+    connect(mResourceCombo, QOverload<int>::of(&Akonadi::CollectionComboBox::activated), this, &KOPrefsDialogColorsAndFonts::updateResourceColor);
     resourceLayout->addWidget(mResourceCombo);
 
     mResourceButton = new KColorButton(resourceGroup);
@@ -1030,7 +1031,7 @@ KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QWidget *pare
 
     // signals and slots connections
 
-    connect(mGroupwarePage->publishDays, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
+    connect(mGroupwarePage->publishDays, QOverload<int>::of(&QSpinBox::valueChanged), this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->publishUrl, &QLineEdit::textChanged, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->publishUser, &QLineEdit::textChanged, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->publishPassword, &QLineEdit::textChanged, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
@@ -1040,7 +1041,7 @@ KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QWidget *pare
     connect(mGroupwarePage->retrievePassword, &QLineEdit::textChanged, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->retrieveSavePassword, &QCheckBox::toggled, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->retrieveUrl, &QLineEdit::textChanged, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
-    connect(mGroupwarePage->publishDelay, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
+    connect(mGroupwarePage->publishDelay, QOverload<int>::of(&QSpinBox::valueChanged), this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->fullDomainRetrieval, &QCheckBox::toggled, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->publishEnable, &QCheckBox::toggled, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
 
@@ -1206,7 +1207,6 @@ KOPrefsDialogPlugins::KOPrefsDialogPlugins(QWidget *parent)
 
     connect(mConfigureButton, &QPushButton::clicked, this, &KOPrefsDialogPlugins::configure);
 
-    //connect( mPositionMonthTop, SIGNAL(clicked()), SLOT(positioningChanged()) );
     connect(mPositionAgendaTop, &QRadioButton::clicked, this, &KOPrefsDialogPlugins::positioningChanged);
     connect(mPositionAgendaBottom, &QRadioButton::clicked, this, &KOPrefsDialogPlugins::positioningChanged);
 
@@ -1383,9 +1383,9 @@ void KOPrefsDialogPlugins::selectionChanged()
         mConfigureButton->setEnabled(item->checkState(0) == Qt::Checked);
     }
 
-    bool hasPosition = false;
     if (item->service()->hasServiceType(
                 EventViews::CalendarDecoration::Decoration::serviceType())) {
+        bool hasPosition = false;
         QString decoration = item->service()->desktopEntryName();
         /*if ( mDecorationsAtMonthViewTop.contains( decoration ) ) {
           mPositionMonthTop->setChecked( true );
