@@ -57,7 +57,7 @@ protected Q_SLOTS:
     void toggleEmailSettings(bool on);
 
 private:
-    QWidget *mUserEmailSettings;
+    QWidget *mUserEmailSettings = nullptr;
 };
 
 class KCM_KORGANIZER_EXPORT KOPrefsDialogColorsAndFonts : public KPIM::KPrefsModule
@@ -80,12 +80,12 @@ protected Q_SLOTS:
     void updateResourceColor();
 
 private:
-    KComboBox     *mCategoryCombo;
-    KColorButton  *mCategoryButton;
+    KComboBox     *mCategoryCombo = nullptr;
+    KColorButton  *mCategoryButton = nullptr;
     QHash<QString, QColor> mCategoryDict;
 
-    Akonadi::CollectionComboBox *mResourceCombo;
-    KColorButton  *mResourceButton;
+    Akonadi::CollectionComboBox *mResourceCombo = nullptr;
+    KColorButton  *mResourceButton = nullptr;
     QHash<QString, QColor> mResourceDict;
 };
 
@@ -114,7 +114,7 @@ protected:
     void usrReadConfig() override;
 
 private:
-    Ui::KOGroupwarePrefsPage *mGroupwarePage;
+    Ui::KOGroupwarePrefsPage *mGroupwarePage = nullptr;
 };
 
 class KCM_KORGANIZER_EXPORT KOPrefsDialogPlugins : public KPIM::KPrefsModule
@@ -132,16 +132,14 @@ protected Q_SLOTS:
 
 private:
     void buildList();
-    QTreeWidget *mTreeWidget;
-    QLabel *mDescription;
-    QPushButton *mConfigureButton;
-    QGroupBox *mPositioningGroupBox;
+    QTreeWidget *mTreeWidget = nullptr;
+    QLabel *mDescription = nullptr;
+    QPushButton *mConfigureButton = nullptr;
+    QGroupBox *mPositioningGroupBox = nullptr;
 
-    //Decorations are not implemented in month view yet
-    //QCheckBox *mPositionMonthTop;
 
-    QRadioButton *mPositionAgendaTop;
-    QRadioButton *mPositionAgendaBottom;
+    QRadioButton *mPositionAgendaTop = nullptr;
+    QRadioButton *mPositionAgendaBottom = nullptr;
     QSet<QString> mDecorationsAtMonthViewTop;
     QSet<QString> mDecorationsAtAgendaViewTop;
     QSet<QString> mDecorationsAtAgendaViewBottom;
