@@ -78,7 +78,7 @@ public:
 
     void setChanges(EventViews::EventView::Changes changes) override;
 
-    void setDateRange(const KDateTime &start, const KDateTime &end,
+    void setDateRange(const QDateTime &start, const QDateTime &end,
                       const QDate &preferredMonth = QDate()) override;
 
 public Q_SLOTS:
