@@ -28,6 +28,10 @@
 
 #include "koeventview.h"
 
+namespace EventViews
+{
+class MonthView;
+}
 namespace KOrg
 {
 
@@ -66,7 +70,7 @@ public:
 
     void setTypeAheadReceiver(QObject *o) override;
 
-    void setDateRange(const KDateTime &start, const KDateTime &end,
+    void setDateRange(const QDateTime &start, const QDateTime &end,
                       const QDate &preferredMonth = QDate()) override;
 
     void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) override;
@@ -89,8 +93,8 @@ private:
     void showDates(const QDate &start, const QDate &end,
                    const QDate &preferredMonth = QDate()) override;
 
-    class Private;
-    Private *const d;
+    EventViews::MonthView *mMonthView = nullptr;
+    KOEventPopupMenu *mPopup = nullptr;
 };
 
 }
